@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "0a2eed962563fd38d31224853f0976a1919de583",
-  "branchName": "release-client-6.x",
-  "buildTime": "2024-09-12 09:22:30 GMT",
-  "buildVersion": "1.0.976",
+  "commitId": "b32683c59914f4a26fc4ae8848494ad58b949282",
+  "branchName": "release-client-6.2.1",
+  "buildTime": "2024-09-23 12:14:36 GMT",
+  "buildVersion": "1.0.1011",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.b08a77b8.css",
     "@zoom/client-scheduler/static/css/index.60f74ba0.css"
   ],
   "js": [
-    "@zoom/client-scheduler/chunk-vendors.27b5c1e6ded2cb8fd048.js",
-    "@zoom/client-scheduler/index.27b5c1e6ded2cb8fd048.js"
+    "@zoom/client-scheduler/chunk-vendors.555e0ea49113c8a3fd64.js",
+    "@zoom/client-scheduler/index.555e0ea49113c8a3fd64.js"
   ],
   "key": "clientSchedulerResource"
 };
